==> RJSplot_2.4.tar.gz: RJSplot/man/tables_rjs.Rd <==
\name{tables_rjs}
\alias{tables_rjs}
\title{Produce interactive html tables.}
\author{
David Barrios and Carlos Prieto. Bioinformatics Service of Nucleus, University of Salamanca. See \url{http://bioinfo.usal.es/}
}
\value{
The function creates a folder in your computer with an HTML document named index.html which contains the table. This file can be directly opened with your browser.
}
\seealso{
  The \sQuote{RJSplot} Website: \url{http://rjsplot.net}

  \code{\link{dendrogram_rjs}}, \code{\link{densityplot_rjs}}, \code{\link{genomemap_rjs}}, \code{\link{heatmap_rjs}}, \code{\link{manhattan_rjs}}, \code{\link{network_rjs}}, \code{\link{scatterplot_rjs}}, \code{\link{symheatmap_rjs}}, \code{\link{wordcloud_rjs}}, \code{\link{boxplot_rjs}}, \code{\link{bubbles_rjs}}, \code{\link{hiveplot_rjs}}, \code{\link{piechart_rjs}}, \code{\link{barplot_rjs}}, \code{\link{tables_rjs}}, \code{\link{surface3d_rjs}}, \code{\link{scatter3d_rjs}}.
}

\usage{
tables_rjs(data, plot = TRUE, jupyter = FALSE, dir = "DataTable")
}
\arguments{
\item{data}{a Data Frame or Matrix to display.}
\item{plot}{open resulting table in your browser.}
\item{jupyter}{embed the graph as an iframe into a Jupyter Notebook.}
\item{dir}{a "character" string representing the directory where the graph will be saved.}
}
\description{
\code{tables_rjs} produce interactive html tables of the given values.
}
\examples{
## Create an interactive html table in the folder "DataTable" of your local machine
## Live examples on http://rjsplot.net
tables_rjs(swiss)
}

==> RJSplot_2.7.tar.gz: RJSplot/man/tables_rjs.Rd <==
\name{tables_rjs}
\alias{tables_rjs}
\title{Produce interactive html tables.}
\author{
David Barrios and Carlos Prieto. Bioinformatics Service of Nucleus, University of Salamanca. See \url{https://bioinfo.usal.es/}
}
\value{
The function creates a folder in your computer with an HTML document named index.html which contains the table. This file can be directly opened with your browser.
}
\seealso{
  The \sQuote{RJSplot} Website: \url{https://rjsplot.usal.es}

  \code{\link{dendrogram_rjs}}, \code{\link{densityplot_rjs}}, \code{\link{genomemap_rjs}}, \code{\link{heatmap_rjs}}, \code{\link{manhattan_rjs}}, \code{\link{network_rjs}}, \code{\link{scatterplot_rjs}}, \code{\link{symheatmap_rjs}}, \code{\link{wordcloud_rjs}}, \code{\link{boxplot_rjs}}, \code{\link{bubbles_rjs}}, \code{\link{hiveplot_rjs}}, \code{\link{piechart_rjs}}, \code{\link{barplot_rjs}}, \code{\link{tables_rjs}}, \code{\link{surface3d_rjs}}, \code{\link{scatter3d_rjs}}.
}

\usage{
tables_rjs(data, plot = TRUE, jupyter = FALSE, dir = tempdir())
}
\arguments{
\item{data}{a Data Frame or Matrix to display.}
\item{plot}{open resulting table in your browser.}
\item{jupyter}{embed the graph as an iframe into a Jupyter Notebook.}
\item{dir}{a "character" string representing the directory where the graph will be saved.}
}
\description{
\code{tables_rjs} produce interactive html tables of the given values.
}
\examples{
## Create an interactive html table in a temporal directory of your local machine
## Live examples on https://rjsplot.usal.es
if(interactive()){
tables_rjs(swiss)
}
}
